# -*- coding: utf-8 -*-
# 测试用例
# 作者: 陈磊
# 时间: 2019-11-11


from __future__ import division

from WorkCase import CaseBase
from WorkUtils.UtilsLog import UtilsLog
from WorkUtils.UtilsDataBase import UtilsDataBase
from WorkUtils.UtilsResponse import UtilsResponse
from WorkApi.API.HostInterface.hostInterface_create import HostInterfaceCreate

from WorkData.Zabbix.interface import DataInterface

import allure

# allure.label("")


@allure.feature("测试模块：hostinterface.create")
class TestHostInterfaceCreate(object):
    log = UtilsLog()
    env = CaseBase().environment
    host = env["host"]
    db_url = env["db_url"]
    db_port = env["db_port"]
    db_user = env["db_user"]
    db_pw = env["db_pw"]
    db_base = env["db_base"]
    base_name = "SS测试主机接口"
    base_ip = "10.0.0.28"
    base_hostid = 10266
    base_dns = "sanshi.zmops.cn"
    base_port = "127"

    @classmethod
    def setup_class(cls):
        cls.log.debug("开始执行测试套件.......")
        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataInterface().delete_hostid(session=session, hostid=cls.base_hostid)

    @classmethod
    def teardown_class(cls):
        cls.log.debug("结束执行测试套件.......")

    def setup_method(self):
        self.log.debug("测试用例执行开始...")

    def teardown_method(self):
        self.log.debug("测试用例执行结束...")

    @allure.step("调用接口：hostinterface.create")
    def hostinterface_create(self, dns=None, hostid=None, ip=None, main=None, port=None, _type=None, useip=None, bulk=None):
        api = HostInterfaceCreate(_host=self.host)
        api.dns = dns
        api.hostid = hostid
        api.ip = ip
        api.main = main
        api.port = port
        api.type = _type
        api.useip = useip
        api.bulk = bulk
        api.get_response()
        return api.response

    @allure.step("连接数据库：zabbix")
    def db_session(self):
        session = UtilsDataBase().conn_mysql(db_url=self.db_url, db_port=self.db_port, db_base=self.db_base, db_user=self.db_user, db_pw=self.db_pw)
        return session

    @allure.step("查询表：interface")
    def select_interface(self, interfaceid=None):
        session = self.db_session()
        sql = DataInterface().select_all_from_allKeys(session=session, interfaceid=interfaceid)
        return sql

    @allure.step("校验查询结果")
    def check_select(self, interfaceid, hostid, main, port, _type, useip, bulk, dns, ip):
        sql = self.select_interface(interfaceid=interfaceid)
        for x, y in enumerate(sql):
            assert y.hostid == hostid
            assert y.main == main
            assert y.port == port
            assert y.type == _type
            assert y.useip == useip
            assert y.bulk == bulk
            if dns != "" and ip == "":
                assert y.dns == dns
            elif ip != "" and dns == "":
                assert y.ip == ip

    @allure.step("断言返回结果：校验排序")
    def check_sortfield(self, response, possible):
        result = UtilsResponse().get_result(response=response)
        UtilsResponse().check_sort(_list=result, key="groupid", possible=possible)

    @allure.step("断言返回结果：校验返回数据的数量")
    def check_num(self, response, num):
        result = UtilsResponse().get_result(response=response)
        assert len(result) == num

    @allure.step("断言返回结果")
    def check_code(self, response, code):
        _code = UtilsResponse().get_code(response=response)
        assert _code == code

    @allure.step("断言返回错误信息")
    def check_msg(self, response, msg):
        _msg = UtilsResponse().get_msg(response=response)
        assert _msg == msg

    @allure.step("断言返回错误结果")
    def check_status(self, response, status):
        _status = UtilsResponse().get_status(response=response)
        assert _status == status

    @allure.title("hostinterface.create：IP地址相应信息")
    @allure.story("创建主机接口：IP地址相应信息")
    @allure.severity("blocker")
    def test_case_01(self):
        response = self.hostinterface_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=1, useip=1, bulk=1)
        self.check_code(response=response, code=0)
        interfaceid = UtilsResponse().get_result(response=response)["interfaceids"][0]
        self.check_select(interfaceid=interfaceid, ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=1, useip=1, bulk=1)

    @allure.title("hostinterface.create：DNS地址相应信息")
    @allure.story("创建主机接口：DNS地址相应信息")
    def test_case_02(self):
        response = self.hostinterface_create(ip="", dns=self.base_dns, hostid=self.base_hostid, main=1, port=self.base_port, _type=2, useip=0, bulk=1)
        self.check_code(response=response, code=0)
        interfaceid = UtilsResponse().get_result(response=response)["interfaceids"][0]
        self.check_select(interfaceid=interfaceid, ip="", dns=self.base_dns, hostid=self.base_hostid, main=1, port=self.base_port, _type=2, useip=0, bulk=1)

    @allure.title("hostinterface.create：默认接口重复添加")
    @allure.story("创建主机接口：默认接口重复添加")
    def test_case_03(self):
        response = self.hostinterface_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=3, useip=1, bulk=1)
        self.check_code(response=response, code=0)
        interfaceid = UtilsResponse().get_result(response=response)["interfaceids"][0]
        self.check_select(interfaceid=interfaceid, ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=3, useip=1, bulk=1)

        response = self.hostinterface_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=3, useip=1, bulk=1)
        self.check_code(response=response, code=100)
        self.check_msg(response=response, msg="主机不能拥有多个同种类型的默认接口")

    @allure.title("hostinterface.create：此类型已有默认 可添加非默认接口")
    @allure.story("创建主机接口：此类型已有默认 可添加非默认接口")
    def test_case_04(self):
        response = self.hostinterface_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=4, useip=1, bulk=1)
        self.check_code(response=response, code=0)
        interfaceid = UtilsResponse().get_result(response=response)["interfaceids"][0]
        self.check_select(interfaceid=interfaceid, ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=4, useip=1, bulk=1)

        response = self.hostinterface_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=0, port=self.base_port, _type=4, useip=1, bulk=1)
        self.check_code(response=response, code=0)
        interfaceid = UtilsResponse().get_result(response=response)["interfaceids"][0]
        self.check_select(interfaceid=interfaceid, ip=self.base_ip, dns="", hostid=self.base_hostid, main=0, port=self.base_port, _type=4, useip=1, bulk=1)

    @allure.title("hostinterface.create：此类型未有默认 无法添加非默认接口")
    @allure.story("创建主机接口：此类型未有默认 无法添加非默认接口")
    def test_case_05(self):
        response = self.hostinterface_create(ip=self.base_ip, dns="", hostid=self.base_hostid, main=0, port=self.base_port, _type=5, useip=1, bulk=1)
        self.check_code(response=response, code=100)
        self.check_msg(response=response, msg="主机11的类型[Unknown interface type]没有默认接口")

    @allure.title("hostinterface.create：useip=0, bulk=1")
    @allure.story("创建主机接口：useip=0, bulk=1")
    def test_case_06(self):
        response = self.hostinterface_create(ip=self.base_ip, dns=self.base_dns, hostid=self.base_hostid, main=1, port=self.base_port, _type=6, useip=0, bulk=1)
        self.check_code(response=response, code=0)
        interfaceid = UtilsResponse().get_result(response=response)["interfaceids"][0]
        self.check_select(interfaceid=interfaceid, ip=self.base_ip, dns="", hostid=self.base_hostid, main=1, port=self.base_port, _type=6, useip=0, bulk=1)


if __name__ == "__main__":
    from WorkUtils.UtilsPyTest import UtilsPyTest
    from WorkUtils.UtilsCmd import UtilsCmd

    import os

    # 执行自动化测试用例
    case_info = os.path.split(__file__)
    case = UtilsCmd().pytest_cmd()
    r = UtilsPyTest(case=case, case_info=case_info)
    r.run_main()

    # a = TestHostInterfaceCreate()
    # a.setup_class()
    # a.test_case_02()
