# -*- coding: utf-8 -*-
# 测试用例
# 作者: 陈磊
# 时间: 2019-11-11


from __future__ import division

from WorkCase import CaseBase
from WorkUtils.UtilsLog import UtilsLog
from WorkUtils.UtilsDataBase import UtilsDataBase
from WorkUtils.UtilsResponse import UtilsResponse
from WorkApi.API.HostPrototype.hostPrototype_create import HostPrototypeCreate

from WorkData.Zabbix.hosts import DataHosts
from WorkData.Zabbix.group_prototype import DataGroupPrototype
from WorkData.Zabbix.host_discovery import DataHostDiscovery

import allure

# allure.label("")


@allure.feature("测试模块：hostprototype.create")
class TestHostPrototypeCreate(object):
    log = UtilsLog()
    env = CaseBase().environment
    host = env["host"]
    db_url = env["db_url"]
    db_port = env["db_port"]
    db_user = env["db_user"]
    db_pw = env["db_pw"]
    db_base = env["db_base"]
    base_name = "SS测试主机原型"
    base_ip = "10.0.0.28"
    base_hostid = 10266
    base_dns = "sanshi.zmops.cn"
    base_port = "127"
    base_hosts = ["{#VM.NAME}", "{#HM.NAME}", "{#VM.UUID}", "{#HV.UUID}"]
    base_ruleid = 10009
    groupLinks_groupid = 46

    new_name = "修改SS测试主机原型"

    @classmethod
    def setup_class(cls):
        cls.log.debug("开始执行测试套件.......")
        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataHosts().delete_name(session=session, name=cls.base_name)

        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataHosts().delete_name(session=session, name=cls.new_name)

    @classmethod
    def teardown_class(cls):
        cls.log.debug("结束执行测试套件.......")

    def setup_method(self):
        self.log.debug("测试用例执行开始...")

    def teardown_method(self):
        self.log.debug("测试用例执行结束...")

    @allure.step("调用接口：hostprototype.create")
    def hostprototype_create(self, host=None, name=None, ruleid=None, templateids=None, groupLinks_groupid=None, groupPrototypes_name=None):
        api = HostPrototypeCreate(_host=self.host)
        api.host = host
        api.name = name
        api.ruleid = ruleid
        api.templateids = templateids
        api.groupLinks_groupid = groupLinks_groupid
        api.groupPrototypes_name = groupPrototypes_name
        api.get_response()
        return api.response

    @allure.step("创建测试数据")
    def case_create(self, host, group_prototypes_name, ruleid):
        response = self.hostprototype_create(host=host, name=self.base_name, ruleid=ruleid, groupLinks_groupid=[self.groupLinks_groupid],
                                             groupPrototypes_name=[group_prototypes_name])
        self.check_code(response=response, code=0)
        hostid = UtilsResponse().get_result(response=response)["hostids"][0]
        return hostid

    @allure.step("连接数据库：zabbix")
    def db_session(self):
        session = UtilsDataBase().conn_mysql(db_url=self.db_url, db_port=self.db_port, db_base=self.db_base, db_user=self.db_user, db_pw=self.db_pw)
        return session

    @allure.step("查询表：hosts")
    def select_hosts(self, hostid=None):
        session = self.db_session()
        sql = DataHosts().select_all_from_allKeys(session=session, hostid=hostid)
        return sql

    @allure.step("查询表：group_prototype")
    def select_group_prototype(self, hostid=None):
        session = self.db_session()
        sql = DataGroupPrototype().select_all_from_allKeys(session=session, hostid=hostid)
        return sql

    @allure.step("查询表：host_discovery")
    def select_host_discovery(self, hostid=None):
        session = self.db_session()
        sql = DataHostDiscovery().select_all_from_allKeys(session=session, hostid=hostid)
        return sql

    @allure.step("校验查询结果")
    def check_select(self, hostid, host, name, flags, groupPrototypes_name, groupid, parent_itemid):
        sql = self.select_hosts(hostid=hostid)
        for x, y in enumerate(sql):
            assert y.host == host
            assert y.name == name
            assert y.flags == flags

        sql = self.select_group_prototype(hostid=hostid)
        assert sql != []
        for x, y in enumerate(sql):
            if y.name is not "":
                # self.log.debug(y.name)
                # self.log.debug(groupPrototypes_name)
                assert y.name == groupPrototypes_name
            elif y.groupid is not "":
                assert y.groupid == groupid

        sql = self.select_host_discovery(hostid=hostid)
        for x, y in enumerate(sql):
            assert y.parent_itemid == parent_itemid

    @allure.step("断言返回结果：校验排序")
    def check_sortfield(self, response, possible):
        result = UtilsResponse().get_result(response=response)
        UtilsResponse().check_sort(_list=result, key="groupid", possible=possible)

    @allure.step("断言返回结果：校验返回数据的数量")
    def check_num(self, response, num):
        result = UtilsResponse().get_result(response=response)
        assert len(result) == num

    @allure.step("断言返回结果")
    def check_code(self, response, code):
        _code = UtilsResponse().get_code(response=response)
        assert _code == code

    @allure.step("断言返回错误信息")
    def check_msg(self, response, msg):
        _msg = UtilsResponse().get_msg(response=response)
        assert _msg == msg

    @allure.step("断言返回错误结果")
    def check_status(self, response, status):
        _status = UtilsResponse().get_status(response=response)
        assert _status == status

    @allure.title("hostprototype.create：在指定规则下新增主机原型，并链接到主机组")
    @allure.story("创建主机原型：在指定规则下新增主机原型，并链接到主机组")
    @allure.severity("blocker")
    def test_case_01(self):
        host = self.base_hosts[0]
        group_prototypes_name = self.base_hosts[0]
        response = self.hostprototype_create(host=host, name=self.base_name, ruleid=self.base_ruleid, groupLinks_groupid=[self.groupLinks_groupid],
                                             groupPrototypes_name=[group_prototypes_name])
        self.check_code(response=response, code=0)
        hostid = UtilsResponse().get_result(response=response)["hostids"][0]
        self.check_select(hostid=hostid, host=host, name=self.base_name, flags=2,
                          groupPrototypes_name=group_prototypes_name, groupid=self.groupLinks_groupid, parent_itemid=self.base_ruleid)


if __name__ == "__main__":
    from WorkUtils.UtilsPyTest import UtilsPyTest
    from WorkUtils.UtilsCmd import UtilsCmd

    import os

    # 执行自动化测试用例
    case_info = os.path.split(__file__)
    case = UtilsCmd().pytest_cmd()
    r = UtilsPyTest(case=case, case_info=case_info)
    r.run_main()

    # a = TestHostPrototypeCreate()
    # a.setup_class()
    # a.test_case_01()
    # a.test_case_02()
    # a.test_case_03()
    # a.test_case_06()
